zfit API documentation
======================

The API documentation of zfit can be found below.
Most classes and functions are documented with docstrings, but don't hesitate to contact us if this documentation is insufficient!

.. toctree::
    :titlesonly:
    :maxdepth: 1

    api/zfit
    api/zfit.pdf
    api/zfit.func
    api/zfit.data
    api/zfit.loss
    api/zfit.constraint
    api/zfit.minimize
    api/zfit.minimizers.fitresult
    api/zfit.settings
    api/zfit.z
